@@ -1,6 +1,6 @@
 package Bundle::DadaMailXXL;
 
-$VERSION = '0.0.4';
+$VERSION = '0.0.5';
 
 1;
 
@@ -60,6 +60,8 @@ Digest::Perl::MD5
 
 Email::Address
 
+Email::Address::XS
+
 Email::Find
 
 Email::Valid
@@ -68,6 +70,8 @@ Exporter::Lite
 
 File::Spec
 
+File::Slurper
+
 Data::Google::Visualization::DataTable
 
 HTML::Entities::Numbered
@@ -94,8 +98,6 @@ Bundle::libnet
 
 Mail::DeliveryStatus::BounceParser 
 
-Email::Address
-
 Mail::Address
 
 Mail::Cap
@@ -140,15 +142,13 @@ MIME::Type
 
 MIME::Types
 
-MIME::Lite
-
-MIME::Lite::HTML
-
 MIME::Tools
 
 Net::SMTP
 
-Net::SMTP_auth 
+Net::SMTP_auth
+
+Number::Bytes::Human
 
 Parse::RecDescent
 
@@ -160,6 +160,8 @@ Scalar-List-Utils
 
 Text::CSV
 
+Text::Markdown
+
 Text::Tabs
 
 Text::Wrap
@@ -168,8 +170,6 @@ Time::Local
 
 Time::Piece
 
-Time::Piece::MySQL
-
 Try::Tiny
 
 URI
